/* Andrey N. Kuznetsov, Almaty, 2012 *
 * For educational purposes.         *
 * Under GPL 2.0                     */
//---------------------------------------------------------------------
#include "TCentralComponent.h"
#include "TStatusBar.h"
//---------------------------------------------------------------------
#define tr(s) String::fromUTF8(s)
//---------------------------------------------------------------------
TCentralComponent::TCentralComponent() : Component ("Central Component"),
                                         pInfoLabel(0),
                                         pToolbar(0)
{
    // Создаём панель инструментов
    pToolbar = new Toolbar();
    addAndMakeVisible(pToolbar);
    // Панель инструментов - горизонтальная
    pToolbar->setVertical(false);
    // Добавляем на панель кнопки
    pToolbar->addDefaultItems(ToolbarFactory);
    // Добавляем слушатель мыши
    pToolbar->addMouseListener(this, true);
    
    // Добавляем слушатели кнопок
    ToolbarFactory.pFileNewButton->addListener(this);
    ToolbarFactory.pFileQuitButton->addListener(this);
    ToolbarFactory.pFileOpenButton->addListener(this);
    ToolbarFactory.pViewOrientationButton->addListener(this);
    
    pInfoLabel = new Label("Info Label", tr("Нажмите кнопку панели инструментов!"));
    pInfoLabel->setJustificationType(Justification::centred);
    pInfoLabel->setColour(Label::backgroundColourId, Colours::azure);
    addAndMakeVisible(pInfoLabel);
    
    // Создаём панель состояния
    pStatusBar = new TStatusBar();
    pStatusBar->ShowHint(tr("Готов"));
    addAndMakeVisible(pStatusBar);

    setSize (400, 200);
}
//---------------------------------------------------------------------
TCentralComponent::~TCentralComponent()
{
    // Удаляем дочерние виджеты
    // и обнуляем их указатели
    deleteAllChildren();
}
//---------------------------------------------------------------------
void TCentralComponent::paint(Graphics& Canvas)
{
    Canvas.fillAll(Colours::azure);
}
//---------------------------------------------------------------------
void TCentralComponent::resized()
{
    if(pToolbar->isVertical())
    {
        pToolbar->setBounds(0, 0, 25, getHeight() - 25);
        pInfoLabel->setBounds(25, proportionOfHeight(0.5000f), proportionOfWidth(1.0000f), 25);
    }
    else
    {
        pToolbar->setBounds(0, 0, getWidth(), 25);
        pInfoLabel->setBounds(0, proportionOfHeight(0.5000f), proportionOfWidth(1.0000f), 25);
    }
    
    pStatusBar->setBounds(0, proportionOfHeight(1.0000f) - 25, proportionOfWidth(1.0000f), 25);
}
//---------------------------------------------------------------------
void TCentralComponent::buttonClicked(Button* pButton)
{
    if(pButton == ToolbarFactory.pFileQuitButton)
    {
        JUCEApplication::quit();
    }
    else if(pButton == ToolbarFactory.pFileNewButton)
    {
        pInfoLabel->setText(tr("Нажата кнопка \"Новый\"."), false);
    }
    else if(pButton == ToolbarFactory.pFileOpenButton)
    {
        pInfoLabel->setText(tr("Нажата кнопка \"Открыть\"."), false);
    }
    else if(pButton == ToolbarFactory.pViewOrientationButton)
    {
        pToolbar->setVertical(!pToolbar->isVertical());
        this->resized();
        pInfoLabel->setText(tr("Нажата кнопка \"Ориентация\"."), false);
    }
}
//---------------------------------------------------------------------
void TCentralComponent::mouseMove(const MouseEvent& Event)
{
    // Отработка показа подсказок кнопок панели инструментов при наведении
    // на них мыши
    if(Event.source.getComponentUnderMouse() == ToolbarFactory.pFileQuitButton)
    {
        pStatusBar->ShowHint(tr("Нажмите, чтобы завершить работу программы"));
    }
    else if(Event.source.getComponentUnderMouse() == ToolbarFactory.pFileNewButton)
    {
        pStatusBar->ShowHint(tr("Нажмите эту кнопку"));
    }
    else if(Event.source.getComponentUnderMouse() == ToolbarFactory.pFileOpenButton)
    {
        pStatusBar->ShowHint(tr("Нажмите эту кнопку"));
    }
    else if(Event.source.getComponentUnderMouse() == ToolbarFactory.pViewOrientationButton)
    {
        pStatusBar->ShowHint(tr("Нажмите эту кнопку, чтобы установить панель инструментов вертикально / горизонтально"));
    }
    else
    {
        pStatusBar->ShowHint(tr("Готов"));
    }
}
//---------------------------------------------------------------------
