/* Andrey N. Kuznetsov, Almaty, 2012 *
 * For educational purposes.         *
 * Under GPL 2.0                     */
//---------------------------------------------------------------------
#include "TToolbarFactory.h"
// Подключаем бинарные ресурсы изображений
#include "TImagesFactory.h"
//---------------------------------------------------------------------
TToolbarFactory::TToolbarFactory()
{
    // Загружаем изображения в объекты класса Image из памяти
    ImageExit_png = ImageCache::getFromMemory(TImagesFactory::psExit_png, TImagesFactory::iExit_pngSize);
    ImageNew_png = ImageCache::getFromMemory(TImagesFactory::psNew_png, TImagesFactory::iNew_pngSize);
    ImageOpen_png = ImageCache::getFromMemory(TImagesFactory::psOpen_png, TImagesFactory::iOpen_pngSize);
    ImageSwitch_png = ImageCache::getFromMemory(TImagesFactory::psRotate_png, TImagesFactory::iRotate_pngSize);
}
//---------------------------------------------------------------------
TToolbarFactory::~TToolbarFactory()
{
}
//---------------------------------------------------------------------
void TToolbarFactory::getAllToolbarItemIds(Array<int>& iIDs)
{
    // Задаём список идентификаторов элементов панели инструментов: 
    // кнопок, разделителей (separators) и распорок (spacers)
    iIDs.add(FileNew);
    iIDs.add(FileOpen);
    iIDs.add(FileQuit);
    iIDs.add(ViewOrientation);
    iIDs.add(spacerId);
    iIDs.add(separatorBarId);
}
//---------------------------------------------------------------------
void TToolbarFactory::getDefaultItemSet(Array<int>& iIDs)
{
    // Определяем порядок добавления элементов на инструментальную панель
    iIDs.add(FileQuit);
    iIDs.add(separatorBarId);
    iIDs.add(FileNew);
    iIDs.add(FileOpen);
    iIDs.add(separatorBarId);
    iIDs.add(ViewOrientation);
}
//---------------------------------------------------------------------
ToolbarItemComponent* TToolbarFactory::createItem(int iItemID)
{
    switch(iItemID)
    {
        // Создаём кнопки панели инструментов, "привязывая" их к ранее созданным идентификаторам
        case FileQuit:
        {
            pFileQuitButton = new ToolbarButton(iItemID, "Quit", Drawable::createFromImageData(TImagesFactory::psExit_png, TImagesFactory::iExit_pngSize),
                                                0);
            return pFileQuitButton;
        }
        case FileNew:
        {
            pFileNewButton = new ToolbarButton(iItemID, "New", Drawable::createFromImageData(TImagesFactory::psNew_png, TImagesFactory::iNew_pngSize),
                                               0);
            return pFileNewButton;
        }
        case FileOpen:
        {
            pFileOpenButton = new ToolbarButton(iItemID, "Open", Drawable::createFromImageData(TImagesFactory::psOpen_png, TImagesFactory::iOpen_pngSize),
                                                0);
            return pFileOpenButton;
        }
        case ViewOrientation:
        {
            pViewOrientationButton = new ToolbarButton(iItemID, "Orientation", Drawable::createFromImageData(TImagesFactory::psRotate_png, TImagesFactory::iRotate_pngSize),
                                                       0);
            return pViewOrientationButton;
        }
        default:
        {
            break;
        }
    }

    return 0;
}
//---------------------------------------------------------------------
